Merge "Set the bucket size to 50 since the improvements show that this is the optimal value."
diff --git a/services/core/java/com/android/server/integrity/model/IndexingFileConstants.java b/services/core/java/com/android/server/integrity/model/IndexingFileConstants.java
index d21febb..0c4052a 100644
--- a/services/core/java/com/android/server/integrity/model/IndexingFileConstants.java
+++ b/services/core/java/com/android/server/integrity/model/IndexingFileConstants.java
@@ -18,9 +18,9 @@
 
 /**  A helper class containing special indexing file constants. */
 public final class IndexingFileConstants {
     // We empirically experimented with different block sizes and identified that 250 is in the
     // optimal range of efficient computation.
-    public static final int INDEXING_BLOCK_SIZE = 250;
+    public static final int INDEXING_BLOCK_SIZE = 50;
 
     public static final String START_INDEXING_KEY = "START_KEY";
     public static final String END_INDEXING_KEY = "END_KEY";
@@ -18,9 +18,9 @@
 /**  A helper class containing special indexing file constants. */
 public final class IndexingFileConstants {
-    // We empirically experimented with different block sizes and identified that 250 is in the
+    // We empirically experimented with different block sizes and identified that 50 is in the
     // optimal range of efficient computation.